# Generated by Django 3.2.25 on 2024-05-30 02:27

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_details", "0006_userdetails_orcid"),
    ]

    operations = [
        migrations.CreateModel(
            name="EducationLevel",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(help_text="The name of the education level", max_length=255, unique=True)),
            ],
            options={
                "ordering": ["name"],
            },
        ),
        migrations.AlterField(
            model_name="ethnicity",
            name="name",
            field=models.CharField(help_text="The name of the ethnicity", max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name="gender",
            name="name",
            field=models.CharField(help_text="The name of the gender", max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name="race",
            name="name",
            field=models.CharField(help_text="The name of the race", max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name="userdetails",
            name="emergency_contact",
            field=models.CharField(blank=True, help_text="The user's emergency contact information", max_length=255),
        ),
        migrations.AddField(
            model_name="userdetails",
            name="education_level",
            field=models.ForeignKey(
                blank=True,
                help_text="The user's education level",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="NEMO_user_details.educationlevel",
            ),
        ),
    ]
