# Generated by Django 4.2.19 on 2025-05-29 20:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_details", "0007_userdetails_education_level"),
    ]

    operations = [
        migrations.AddField(
            model_name="userdetails",
            name="google_scholar_id",
            field=models.CharField(
                blank=True,
                help_text="The user's Google Scholar ID",
                max_length=255,
                null=True,
                verbose_name="Google scholar ID",
            ),
        ),
        migrations.AddField(
            model_name="userdetails",
            name="researcher_id",
            field=models.CharField(
                blank=True,
                help_text="The user's Web of Science Researcher ID",
                max_length=255,
                null=True,
                verbose_name="Researcher ID",
            ),
        ),
        migrations.AddField(
            model_name="userdetails",
            name="scopus_id",
            field=models.CharField(
                blank=True, help_text="The user's Scopus ID", max_length=255, null=True, verbose_name="Scopus ID"
            ),
        ),
    ]
