# Generated by Django 3.2.16 on 2023-01-20 14:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_details", "0002_version_1_1_0"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="userdetails",
            name="rate_category_id",
        ),
        migrations.RemoveField(
            model_name="userdetails",
            name="rate_category_type",
        ),
    ]
