# Generated by Django 3.2.16 on 2022-12-26 02:50

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("NEMO_user_details", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="userdetails",
            name="rate_category_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="userdetails",
            name="rate_category_type",
            field=models.ForeignKey(
                blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to="contenttypes.contenttype"
            ),
        ),
    ]
