# Generated by Django 3.2.19 on 2023-05-25 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_details", "0003_version_1_3_0"),
    ]

    operations = [
        migrations.AddField(
            model_name="userdetails",
            name="employee_id",
            field=models.CharField(blank=True, help_text="The user's internal employee id", max_length=255),
        ),
    ]
