# Generated by Django 3.2.22 on 2023-12-13 15:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_details", "0005_alter_userdetails_employee_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="userdetails",
            name="orcid",
            field=models.CharField(
                blank=True, help_text="The user's ORCID", max_length=255, null=True, verbose_name="ORCID"
            ),
        ),
    ]
